/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* Balsa E-Mail Client
 * Copyright (C) 1997-2002 Stuart Parmenter and others,
 *                         See the file AUTHORS for a list.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */
 


#include <Bonobo.idl>

module GNOME {
	module Balsa {
		interface Composer : Bonobo::Unknown {
			
			typedef sequence<string> attachs;
			
			void sendMessage (in string from, in string to, in string cc,
							  in string subject, in attachs attachments,
							  in boolean nogui );
			
		};
		
		interface Application : Bonobo::Unknown {
			
			void checkmail ( );
			void openMailbox (in string name);
			void openUnread ( );
			void openInbox ( );
			void getStats (out long unread, out long unsent);
		};
	};
};
